# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LinParserNode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Common_pb2 as Common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13LinParserNode.proto\x12\rLinParserNode\x1a\x0c\x43ommon.proto\"C\n\x0flin_node_config\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\x05\x12\x0c\n\x04simu\x18\x03 \x01(\x08\"W\n\x10lin_frame_config\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\x05\x12\x12\n\nframe_name\x18\x02 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x03 \x01(\x05\x12\x0c\n\x04simu\x18\x04 \x01(\x08\"o\n\x12lin_channel_config\x12\x10\n\x08ldf_path\x18\x01 \x01(\t\x12\x10\n\x08lin_mode\x18\x02 \x01(\t\x12\x0e\n\x06txrecv\x18\x03 \x01(\x05\x12\x10\n\x08\x62\x61udrate\x18\x04 \x01(\x03\x12\x13\n\x0blin_channel\x18\x05 \x01(\x05\"W\n\x11lin_parser_status\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x12\n\nstr_status\x18\x03 \x01(\t\"A\n\x0clin_ldf_json\x12\x0e\n\x06result\x18\x01 \x01(\x05\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x11\n\tjson_data\x18\x03 \x01(\t2\xa7\x04\n\rLinParserNode\x12\x30\n\tAddDbfile\x12\x11.Common.file_path\x1a\x0e.Common.result\"\x00\x12G\n\x10SetChannelConfig\x12!.LinParserNode.lin_channel_config\x1a\x0e.Common.result\"\x00\x12\x45\n\x11SetNodeSimulation\x12\x1e.LinParserNode.lin_node_config\x1a\x0e.Common.result\"\x00\x12G\n\x12SetFrameSimulation\x12\x1f.LinParserNode.lin_frame_config\x1a\x0e.Common.result\"\x00\x12(\n\x05\x43lear\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12\x31\n\x0e\x43learSubscribe\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12.\n\x0b\x43learDbfile\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12>\n\tGetStatus\x12\r.Common.empty\x1a .LinParserNode.lin_parser_status\"\x00\x12>\n\x0eGetLdfJsonTree\x12\r.Common.empty\x1a\x1b.LinParserNode.lin_ldf_json\"\x00\x62\x06proto3')



_LIN_NODE_CONFIG = DESCRIPTOR.message_types_by_name['lin_node_config']
_LIN_FRAME_CONFIG = DESCRIPTOR.message_types_by_name['lin_frame_config']
_LIN_CHANNEL_CONFIG = DESCRIPTOR.message_types_by_name['lin_channel_config']
_LIN_PARSER_STATUS = DESCRIPTOR.message_types_by_name['lin_parser_status']
_LIN_LDF_JSON = DESCRIPTOR.message_types_by_name['lin_ldf_json']
lin_node_config = _reflection.GeneratedProtocolMessageType('lin_node_config', (_message.Message,), {
  'DESCRIPTOR' : _LIN_NODE_CONFIG,
  '__module__' : 'LinParserNode_pb2'
  # @@protoc_insertion_point(class_scope:LinParserNode.lin_node_config)
  })
_sym_db.RegisterMessage(lin_node_config)

lin_frame_config = _reflection.GeneratedProtocolMessageType('lin_frame_config', (_message.Message,), {
  'DESCRIPTOR' : _LIN_FRAME_CONFIG,
  '__module__' : 'LinParserNode_pb2'
  # @@protoc_insertion_point(class_scope:LinParserNode.lin_frame_config)
  })
_sym_db.RegisterMessage(lin_frame_config)

lin_channel_config = _reflection.GeneratedProtocolMessageType('lin_channel_config', (_message.Message,), {
  'DESCRIPTOR' : _LIN_CHANNEL_CONFIG,
  '__module__' : 'LinParserNode_pb2'
  # @@protoc_insertion_point(class_scope:LinParserNode.lin_channel_config)
  })
_sym_db.RegisterMessage(lin_channel_config)

lin_parser_status = _reflection.GeneratedProtocolMessageType('lin_parser_status', (_message.Message,), {
  'DESCRIPTOR' : _LIN_PARSER_STATUS,
  '__module__' : 'LinParserNode_pb2'
  # @@protoc_insertion_point(class_scope:LinParserNode.lin_parser_status)
  })
_sym_db.RegisterMessage(lin_parser_status)

lin_ldf_json = _reflection.GeneratedProtocolMessageType('lin_ldf_json', (_message.Message,), {
  'DESCRIPTOR' : _LIN_LDF_JSON,
  '__module__' : 'LinParserNode_pb2'
  # @@protoc_insertion_point(class_scope:LinParserNode.lin_ldf_json)
  })
_sym_db.RegisterMessage(lin_ldf_json)

_LINPARSERNODE = DESCRIPTOR.services_by_name['LinParserNode']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LIN_NODE_CONFIG._serialized_start=52
  _LIN_NODE_CONFIG._serialized_end=119
  _LIN_FRAME_CONFIG._serialized_start=121
  _LIN_FRAME_CONFIG._serialized_end=208
  _LIN_CHANNEL_CONFIG._serialized_start=210
  _LIN_CHANNEL_CONFIG._serialized_end=321
  _LIN_PARSER_STATUS._serialized_start=323
  _LIN_PARSER_STATUS._serialized_end=410
  _LIN_LDF_JSON._serialized_start=412
  _LIN_LDF_JSON._serialized_end=477
  _LINPARSERNODE._serialized_start=480
  _LINPARSERNODE._serialized_end=1031
# @@protoc_insertion_point(module_scope)



import ctypes
import typing
import json


class BLF_ObjectType(object):
    UNKNOWN = 0 # /**< unknown object */
    CAN_MESSAGE = 1 # /**< CAN message object */
    CAN_ERROR = 2 # /**< CAN error frame object */
    CAN_OVERLOAD = 3 # /**< CAN overload frame object */
    CAN_STATISTIC = 4 # /**< CAN driver statistics object */
    APP_TRIGGER = 5 # /**< application trigger object */
    ENV_INTEGER = 6 # /**< environment integer object */
    ENV_DOUBLE = 7 # /**< environment double object */
    ENV_STRING = 8 # /**< environment string object */
    ENV_DATA = 9 # /**< environment data object */
    LOG_CONTAINER = 10 # /**< container object */
    LIN_MESSAGE = 11 # /**< LIN message object */
    LIN_CRC_ERROR = 12 # /**< LIN CRC error object */
    LIN_DLC_INFO = 13 # /**< LIN DLC info object */
    LIN_RCV_ERROR = 14 # /**< LIN receive error object */
    LIN_SND_ERROR = 15 # /**< LIN send error object */
    LIN_SLV_TIMEOUT = 16 # /**< LIN slave timeout object */
    LIN_SCHED_MODCH = 17 # /**< LIN scheduler mode change object */
    LIN_SYN_ERROR = 18 # /**< LIN sync error object */
    LIN_BAUDRATE = 19 # /**< LIN baudrate event object */
    LIN_SLEEP = 20 # /**< LIN sleep mode event object */
    LIN_WAKEUP = 21 # /**< LIN wakeup event object */
    MOST_SPY = 22 # /**< MOST spy message object */
    MOST_CTRL = 23 # /**< MOST control message object */
    MOST_LIGHTLOCK = 24 # /**< MOST light lock object */
    MOST_STATISTIC = 25 # /**< MOST statistic object */
    Reserved26 = 26 # /**< reserved */
    Reserved27 = 27 # /**< reserved */
    Reserved28 = 28 # /**< reserved */
    FLEXRAY_DATA = 29 # /**< FLEXRAY data object */
    FLEXRAY_SYNC = 30 # /**< FLEXRAY sync object */
    CAN_DRIVER_ERROR = 31 # /**< CAN driver error object */
    MOST_PKT = 32 # /**< MOST Packet */
    MOST_PKT2 = 33 # /**< MOST Packet including original timestamp */
    MOST_HWMODE = 34 # /**< MOST hardware mode event */
    MOST_REG = 35 # /**< MOST register data (various chips) */
    MOST_GENREG = 36 # /**< MOST register data (MOST register) */
    MOST_NETSTATE = 37 # /**< MOST NetState event */
    MOST_DATALOST = 38 # /**< MOST data lost */
    MOST_TRIGGER = 39 # /**< MOST trigger */
    FLEXRAY_CYCLE = 40 # /**< FLEXRAY V6 start cycle object */
    FLEXRAY_MESSAGE = 41 # /**< FLEXRAY V6 message object */
    LIN_CHECKSUM_INFO = 42 # /**< LIN checksum info event object */
    LIN_SPIKE_EVENT = 43 # /**< LIN spike event object */
    CAN_DRIVER_SYNC = 44 # /**< CAN driver hardware sync */
    FLEXRAY_STATUS = 45 # /**< FLEXRAY status event object */
    GPS_EVENT = 46 # /**< GPS event object */
    FR_ERROR = 47 # /**< FLEXRAY error event object */
    FR_STATUS = 48 # /**< FLEXRAY status event object */
    FR_STARTCYCLE = 49 # /**< FLEXRAY start cycle event object */
    FR_RCVMESSAGE = 50 # /**< FLEXRAY receive message event object */
    REALTIMECLOCK = 51 # /**< Realtime clock object */
    Reserved52 = 52 # /**< this object ID is available for the future */
    Reserved53 = 53 # /**< this object ID is available for the future */
    LIN_STATISTIC = 54 # /**< LIN statistic event object */
    J1708_MESSAGE = 55 # /**< J1708 message object */
    J1708_VIRTUAL_MSG = 56 # /**< J1708 message object with more than 21 data bytes */
    LIN_MESSAGE2 = 57 # /**< LIN frame object - extended */
    LIN_SND_ERROR2 = 58 # /**< LIN transmission error object - extended */
    LIN_SYN_ERROR2 = 59 # /**< LIN sync error object - extended */
    LIN_CRC_ERROR2 = 60 # /**< LIN checksum error object - extended */
    LIN_RCV_ERROR2 = 61 # /**< LIN receive error object */
    LIN_WAKEUP2 = 62 # /**< LIN wakeup event object  - extended */
    LIN_SPIKE_EVENT2 = 63 # /**< LIN spike event object - extended */
    LIN_LONG_DOM_SIG = 64 # /**< LIN long dominant signal object */
    APP_TEXT = 65 # /**< text object */
    FR_RCVMESSAGE_EX = 66 # /**< FLEXRAY receive message ex event object */
    MOST_STATISTICEX = 67 # /**< MOST extended statistic event */
    MOST_TXLIGHT = 68 # /**< MOST TxLight event */
    MOST_ALLOCTAB = 69 # /**< MOST Allocation table event */
    MOST_STRESS = 70 # /**< MOST Stress event */
    ETHERNET_FRAME = 71 # /**< Ethernet frame object */
    SYS_VARIABLE = 72 # /**< system variable object */
    CAN_ERROR_EXT = 73 # /**< CAN error frame object (extended) */
    CAN_DRIVER_ERROR_EXT = 74 # /**< CAN driver error object (extended) */
    LIN_LONG_DOM_SIG2 = 75 # /**< LIN long dominant signal object - extended */
    MOST_150_MESSAGE = 76 # /**< MOST150 Control channel message */
    MOST_150_PKT = 77 # /**< MOST150 Asynchronous channel message */
    MOST_ETHERNET_PKT = 78 # /**< MOST Ethernet channel message */
    MOST_150_MESSAGE_FRAGMENT = 79 # /**< Partial transmitted MOST50/150 Control channel message */
    MOST_150_PKT_FRAGMENT = 80 # /**< Partial transmitted MOST50/150 data packet on asynchronous channel */
    MOST_ETHERNET_PKT_FRAGMENT = 81 # /**< Partial transmitted MOST Ethernet packet on asynchronous channel */
    MOST_SYSTEM_EVENT = 82 # /**< Event for various system states on MOST */
    MOST_150_ALLOCTAB = 83 # /**< MOST50/150 Allocation table event */
    MOST_50_MESSAGE = 84 # /**< MOST50 Control channel message */
    MOST_50_PKT = 85 # /**< MOST50 Asynchronous channel message */
    CAN_MESSAGE2 = 86 # /**< CAN message object - extended */
    LIN_UNEXPECTED_WAKEUP = 87,
    LIN_SHORT_OR_SLOW_RESPONSE = 88,
    LIN_DISTURBANCE_EVENT = 89,
    SERIAL_EVENT = 90,
    OVERRUN_ERROR = 91 # /**< driver overrun event */
    EVENT_COMMENT = 92,
    WLAN_FRAME = 93,
    WLAN_STATISTIC = 94,
    MOST_ECL = 95 # /**< MOST Electrical Control Line event */
    GLOBAL_MARKER = 96,
    AFDX_FRAME = 97,
    AFDX_STATISTIC = 98,
    KLINE_STATUSEVENT = 99 # /**< E.g. wake-up pattern */
    CAN_FD_MESSAGE = 100 # /**< CAN FD message object */
    CAN_FD_MESSAGE_64 = 101 # /**< CAN FD message object */
    ETHERNET_RX_ERROR = 102 # /**< Ethernet RX error object */
    ETHERNET_STATUS = 103 # /**< Ethernet status object */
    CAN_FD_ERROR_64 = 104 # /**< CAN FD Error Frame object */
    LIN_SHORT_OR_SLOW_RESPONSE2 = 105,
    AFDX_STATUS = 106 # /**< AFDX status object */
    AFDX_BUS_STATISTIC = 107 # /**< AFDX line-dependent busstatistic object */
    Reserved108 = 108,
    AFDX_ERROR_EVENT = 109 # /**< AFDX asynchronous error event */
    A429_ERROR = 110 # /**< A429 error object */
    A429_STATUS = 111 # /**< A429 status object */
    A429_BUS_STATISTIC = 112 # /**< A429 busstatistic object */
    A429_MESSAGE = 113 # /**< A429 Message */
    ETHERNET_STATISTIC = 114 # /**< Ethernet statistic object */
    Unknown115 = 115,
    Reserved116 = 116,
    Reserved117 = 117,
    TEST_STRUCTURE = 118 # /**< Event for test execution flow */
    DIAG_REQUEST_INTERPRETATION = 119 # /**< Event for correct interpretation of diagnostic requests */
    ETHERNET_FRAME_EX = 120 # /**< Ethernet packet extended object */
    ETHERNET_FRAME_FORWARDED = 121 # /**< Ethernet packet forwarded object */
    ETHERNET_ERROR_EX = 122 # /**< Ethernet error extended object */
    ETHERNET_ERROR_FORWARDED = 123 # /**< Ethernet error forwarded object */
    FUNCTION_BUS = 124 # /**< FunctionBus object */
    DATA_LOST_BEGIN = 125 # /**< Data lost begin */
    DATA_LOST_END = 126 # /**< Data lost end */
    WATER_MARK_EVENT = 127 # /**< Watermark event */
    TRIGGER_CONDITION = 128 # /**< Trigger Condition event */
    CAN_SETTING_CHANGED = 129 # /**< CAN Settings Changed object */
    DISTRIBUTED_OBJECT_MEMBER = 130 # /**< Distributed object member (communication setup) */
    ATTRIBUTE_EVENT = 131 # /**< ATTRIBUTE event (communication setup) */

    LIN_FRAME = 140    # 解析后的 LINFrame
    CAN_FRAME = 141    # 解析后的 CANFrame
    CAN_I_SIGNAL_I_PDU = 142    # PDU 对象
    ETH_SOMEIP = 143    # 解析后的 someip 报文
    ETH_SOMEIP_SD = 144 # 解析后的 SD

    
class BlfIoStruct(ctypes.Structure):
    def __init__(self) -> None:
        super().__init__()
        self._blfObjType = BLF_ObjectType.UNKNOWN
        self.children = dict()
        self.channel = 0

    def ToDict(self) -> dict:
        '''
        转换成 字典，也是转换为 bytes 的其中一步
        '''
        return {
            '_blfObjType':self._blfObjType
        }

    def ToBytes(self) -> bytes:
        '''
        序列化为 bytes
        '''
        return self._blfObjType.to_bytes(length=1, byteorder='big', signed=False) + bytes(json.dumps(self.ToDict()), encoding='utf-8')

    def Data(self) -> typing.List[int]:
        '''
        获取 python 型的数据
        '''
        # return list(ctypes.string_at(self._exportData, self._dataLength))
        return []

    def Feature(self) -> typing.Tuple:
        '''
        获取该 obj 的Feature
        '''
        return tuple()

    def TypeStr(self) -> str:
        '''
        获取类型的字符串描述
        '''
        return 'NONE'

    def DirStr(self) -> str:
        '''
        获取 字符串类型的方向
        '''
        return ''

class ObjectHeaderPy(BlfIoStruct):
    _fields_ = [
        ('signature', ctypes.c_uint32),
        ("headerSize", ctypes.c_uint16),
        ("headerVersion", ctypes.c_uint16),
        ("objectSize", ctypes.c_uint32),
        ("objectType", ctypes.c_uint32),
        ("objectFlags", ctypes.c_uint32),
        ("clientIndex", ctypes.c_uint16),
        ("objectVersion", ctypes.c_uint16),
        ("objectTimeStamp", ctypes.c_uint64),
        ]

class ObjectHeader2Py(BlfIoStruct):
    _fields_ = [
        ('signature', ctypes.c_uint32),
        ("headerSize", ctypes.c_uint16),
        ("headerVersion", ctypes.c_uint16),
        ("objectSize", ctypes.c_uint32),
        ("objectType", ctypes.c_uint32),
        ("objectFlags", ctypes.c_uint32),
        ("timeStampStatus", ctypes.c_uint8),
        ("reservedObjectHeader", ctypes.c_uint8),
        ("objectVersion", ctypes.c_uint16),
        ("objectTimeStamp", ctypes.c_uint64),
        ("originalTimeStamp", ctypes.c_uint64),
        ]

class CanFdMessagePy(BlfIoStruct):
    _fields_ =[
        ('channel', ctypes.c_uint8),
        ('flags', ctypes.c_uint8),
        ('dlc', ctypes.c_uint8),
        ('id', ctypes.c_uint32),
        ('frameLength', ctypes.c_uint32),
        ('arbBitCount', ctypes.c_uint8),
        ('canFdFlags', ctypes.c_uint8),
        ('validDataBytes', ctypes.c_uint8),
        ('reservedCanFdMessage1', ctypes.c_uint8),
        ('reservedCanFdMessage2', ctypes.c_uint32),
        ('data', ctypes.c_int8*64),
        ('reservedCanFdMessage3', ctypes.c_uint32),
        ('_dataLength', ctypes.c_uint16),
    ]
    INDEX_MAP_DIR_STR = ['Tx', 'Rx']
    def __init__(
        self,
        channel:int=0,
        flags:int=0x1000,
        dlc:int=0,
        id:int=0,
        frameLength:int=0,
        arbBitCount:int=0,
        canFdFlags:int=0x01,
        validDataBytes:int=0,
        reservedCanFdMessage1:int=0,
        reservedCanFdMessage2:int=0,
        data:typing.List[int]=[],
        reservedCanFdMessage3:int=0) -> None:
        '''
        CanFdMessage Object
        :param channel:int 通道
        :param flags:int flags
            - Bit0:TX
            - Bit5:NERR
            - Bit6:WU
            - Bit7:RTR
        :param dlc:int dlc
        :param id:int id
        :param frameLength:int 报文长度 非必须
        :param arbBitCount:int 仲裁场的数据长度 非必须
        :param canFdFlags:int canFdFlags 非必须
            - Bit0:EDL
            - Bit1:BRS
            - Bit2:ESI
        :param validDataBytes:int 有效的数据场长度 非必须
        :param reservedCanFdMessage1:int 保留 非必须
        :param reservedCanFdMessage2:int 保留 非必须
        :param data:list[int] 数据场 需要和 dlc 匹配
        :param reservedCanFdMessage3:int 保留
        '''
        super().__init__()
        self.channel = channel
        self.flags = flags
        self.dlc = dlc
        self.id = id
        self.frameLength = frameLength
        self.arbBitCount = arbBitCount
        self.canFdFlags = canFdFlags
        self.validDataBytes = validDataBytes
        self.reservedCanFdMessage1 = reservedCanFdMessage1
        self.reservedCanFdMessage2 = reservedCanFdMessage2
        self.reservedCanFdMessage3 = reservedCanFdMessage3
        self._dataLength = len(data)
        self.data = (ctypes.c_int8*64)(*data)
        self._blfObjType = BLF_ObjectType.CAN_FD_MESSAGE

    def ToDict(self) -> dict:
        d_ = super().ToDict()
        d_.update({
            'channel': self.channel,
            'flags': self.flags,
            'dlc': self.dlc,
            'id': self.id,
            'frameLength': self.frameLength,
            'arbBitCount': self.arbBitCount,
            'canFdFlags': self.canFdFlags,
            'validDataBytes': self.validDataBytes,
            'reservedCanFdMessage1': self.reservedCanFdMessage1,
            'reservedCanFdMessage2': self.reservedCanFdMessage2,
            'reservedCanFdMessage3': self.reservedCanFdMessage3,
            'data': list(ctypes.string_at(self.data, self._dataLength)),
        })
        return d_

    def Data(self) -> typing.List[int]:
        return list(ctypes.string_at(self.data, self._dataLength))

    def Feature(self) -> typing.Tuple:
        # return super().Feature()
        return (self._blfObjType, self.id, self.channel)

    def TypeStr(self) -> str:
        return 'CanFdMessage'

    def DirStr(self) -> str:
        dir_flg_ = self.flags & 0x01
        return self.INDEX_MAP_DIR_STR[dir_flg_]

class CanFdMessage64Py(BlfIoStruct):
    _fields_ =[
        ('channel', ctypes.c_uint8),
        ('dlc', ctypes.c_uint8),
        ('validDataBytes', ctypes.c_uint8),
        ('txCount', ctypes.c_uint8),
        ('id', ctypes.c_uint32),
        ('frameLength', ctypes.c_uint32),
        ('flags', ctypes.c_uint32),
        ('btrCfgArb', ctypes.c_uint32),
        ('btrCfgData', ctypes.c_uint32),
        ('timeOffsetBrsNs', ctypes.c_uint32),
        ('timeOffsetCrcDelNs', ctypes.c_uint32),
        ('dir', ctypes.c_uint8),
        ('extDataOffset', ctypes.c_uint8),
        ('crc', ctypes.c_uint32),
        ('data', ctypes.c_uint8*64),
        ('_dataLength', ctypes.c_uint16),
    ]
    INDEX_MAP_DIR_STR = ['Tx', 'Rx']
    def __init__(
        self, 
        channel: int = 0, 
        dlc: int = 0, 
        validDataBytes: int = 0, 
        txCount: int=0, 
        id: int=0, 
        frameLength: int = 0, 
        flags: int=0x1000,
        btrCfgArb: int=0,
        btrCfgData: int=0,
        timeOffsetBrsNs: int=0,
        timeOffsetCrcDelNs: int=0,
        dir:int=0,
        extDataOffset: int=0,
        crc: int=0,
        data: list = []) -> None:
        '''
        CanFdMessage64 Object
        :param channel:int 通道
        :param dlc:int dlc
        :param validDataBytes:int 有效的数据场长度 非必须
        :param txCount:int txQuiredCount 和 txReqCount
            - Bits(0-3):required tranmission 数量
            - Bits(4-7):transmission attempts 的最大数量
        :param id:int id
        :param frameLength:int 报文长度 非必须
        :param flags:int flags
            - Bit0:0x0001 一定是 0
            - Bit1:0x0002 保留
            - Bit2:0x0004 1=NERR
            - Bit3:0x0008 1=High voltage 唤醒
            - Bit4:0x0010 1=远程帧
            - Bit5:0x0020 保留为0
            - Bit6:0x0040 1=Tx Ack
            - Bit7:0x0080 1=Tx Request
            - Bit8:0x0100 保留
            - Bit9:0x0200 SRR(CANFD)
            - Bit10:0x0400 R0
            - Bit11:0x0800 R1
            - Bit12:0x1000 EDL
            - Bit13:0x2000 BRS(CANFD)
            - Bit14:0x4000 ESI
            - Bit15:0x8000 保留
            - Bit16:0x10000 保留
            - Bit17:0x20000 1=Frame 是 burst 的一部分
            - Bit18-31:保留
        :param btrCfgArb:int 仲裁场的配置 非必须
            - Bit0-7:晶振频率
            - Bit8-15:预分频系数
            - Bit16-23:BTL Cycles
            - Bit24-31:采样点
        :param btrCfgData:int 数据场的配置 为 0 非必须
        :param timeOffsetBrsNs:int brs 场的时间偏移 非必须
        :param timeOffsetCrcDelNs:int time offset of crc delimiter field 非必须
        :param bitCount:int 完整的数据长度 非必须
        :param dir:int message 的方向
        :param extDataOffset:int 如果 extDataOffset 使用的话，其偏移 非必须
        :param crc:int message 的 crc 非必须
        :param data:list[int] message 数据
        '''
        super().__init__()
        self.channel = channel
        self.dlc = dlc
        self.validDataBytes = validDataBytes
        self.txCount = txCount
        self.id = id
        self.frameLength = frameLength
        self.flags = flags
        self.btrCfgArb = btrCfgArb
        self.btrCfgData = btrCfgData
        self.timeOffsetBrsNs = timeOffsetBrsNs
        self.timeOffsetCrcDelNs = timeOffsetCrcDelNs
        self.dir = dir
        self.extDataOffset = extDataOffset
        self.crc = crc
        self.data = (ctypes.c_uint8 * 64)(*data)
        self._dataLength = len(data)
        self._blfObjType = BLF_ObjectType.CAN_FD_MESSAGE_64

    def ToDict(self) -> dict:
        # return super().ToDict()
        # print('channel.type {0}, data.type {1}'.format(type(self.channel), type(list(ctypes.string_at(self.data, self._dataLength))[0])))
        d_ = super().ToDict()
        d_.update({
            'channel': self.channel,
            'dlc': self.dlc,
            'validDataBytes': self.validDataBytes,
            'txCount': self.txCount,
            'id': self.id,
            'frameLength': self.frameLength,
            'flags': self.flags,
            'btrCfgArb': self.btrCfgArb,
            'btrCfgData': self.btrCfgData,
            'timeOffsetBrsNs': self.timeOffsetBrsNs,
            'timeOffsetCrcDelNs': self.timeOffsetCrcDelNs,
            'dir': self.dir,
            'extDataOffset': self.extDataOffset,
            'crc': self.crc,
            'data': list(ctypes.string_at(self.data, self._dataLength)),
        })
        return d_

    def Data(self) -> typing.List[int]:
        return list(ctypes.string_at(self.data, self._dataLength))

    def Feature(self) -> typing.Tuple:
        # return super().Feature()
        return (self._blfObjType, self.id, self.channel)

    def TypeStr(self) -> str:
        return 'CanFdMessage64'

    def DirStr(self) -> str:
        return self.INDEX_MAP_DIR_STR[self.dir]

class CanMessagePy(BlfIoStruct):
    _fields_ =[
        ('channel', ctypes.c_uint16),
        ('flags', ctypes.c_uint8),
        ('dlc', ctypes.c_uint8),
        ('id', ctypes.c_uint32),
        ('data', ctypes.c_uint8*8),
        ('_dataLength', ctypes.c_uint16),
    ]
    INDEX_MAP_DIR_STR = ['Tx', 'Rx']
    def __init__(
        self,
        channel:int = 0,
        flags:int = 0,
        dlc:int=0,
        id:int=0,
        data:typing.List[int]=[]) -> None:
        '''
        CanMessage Object
        :param channel:int 通道
        :param flags:int
            - Bit 0:TX
            - Bit 5:NERR
            - Bit 6:WU
            - Bit 7:RTR
        :param dlc:int dlc
        :param id:int id
        :param data:list[int] 需要和dlc匹配
        '''
        super().__init__()
        self.channel = channel
        self.flags = flags
        self.dlc = dlc
        self.id = id
        self.data = (ctypes.c_uint8 * 8)(*data)
        self._dataLength = len(data)
        self._blfObjType = BLF_ObjectType.CAN_MESSAGE

    def ToDict(self) -> dict:
        # return super().ToDict()
        d_ = super().ToDict()
        d_.update({
            'channel': self.channel,
            'flags': self.flags,
            'dlc': self.dlc,
            'id': self.id,
            'data': list(ctypes.string_at(self.data, self._dataLength)),
        })
        return d_

    def Data(self) -> typing.List[int]:
        return list(ctypes.string_at(self.data, self._dataLength))

    def Feature(self) -> typing.Tuple:
        return (self._blfObjType, self.id, self.channel)

    def TypeStr(self) -> str:
        return 'CanMessage'

    def DirStr(self) -> str:
        dir_flag_ = self.flags & 0x01
        return self.INDEX_MAP_DIR_STR[dir_flag_]

class CanMessage2Py(BlfIoStruct):
    _fields_ =[
        ('channel', ctypes.c_uint16),
        ('flags', ctypes.c_uint8),
        ('dlc', ctypes.c_uint8),
        ('id', ctypes.c_uint32),
        ('data', ctypes.c_uint8*8),
        ('frameLength', ctypes.c_uint32),
        ('bitCount', ctypes.c_uint8),
        ('reservedCanMessage1', ctypes.c_uint8),
        ('reservedCanMessage2', ctypes.c_uint16),
        ('_dataLength', ctypes.c_uint16),
    ]
    INDEX_MAP_DIR_STR = ['Tx', 'Rx']
    def __init__(
        self,
        channel:int=0,
        flags:int=0,
        dlc:int=0,
        id:int=0,
        data:typing.List[int]=[],
        frameLength:int=0,
        bitCount:int=0,
        reservedCanMessage1:int=0,
        reservedCanMessage2:int=0) -> None:
        super().__init__()
        '''
        CanMessage2 Object
        :param channel:int channel
        :param flags:int
            - Bit 0:TX
            - Bit 5:NERR
            - Bit 6:WU
            - Bit 7:RTR
        :param dlc:int dlc
        :param id:int id
        :param data:list[int] 需要和dlc匹配
        :param frameLength:int 报文长度 非必须
        :param bitCount:int 报文完成的 Bit 长度 非必须
        :param reservedCanMessage1:int 保留
        :param reservedCanMessage2:int 保留
        '''
        self.channel = channel
        self.flags = flags
        self.dlc = dlc
        self.id = id
        self.data = (ctypes.c_uint8*8)(*data)
        self.frameLength = frameLength
        self.bitCount = bitCount
        self.reservedCanMessage1 = reservedCanMessage1
        self.reservedCanMessage2 = reservedCanMessage2
        self._dataLength = len(data)
        self._blfObjType = BLF_ObjectType.CAN_MESSAGE2

    def ToDict(self) -> dict:
        d_ = super().ToDict()
        d_.update({
            'channel': self.channel,
            'flags': self.flags,
            'dlc': self.dlc,
            'id': self.id,
            'data': list(ctypes.string_at(self.data, self._dataLength)),
            'frameLength': self.frameLength,
            'bitCount': self.bitCount,
            'reservedCanMessage1': self.reservedCanMessage1,
            'reservedCanMessage2': self.reservedCanMessage2,
        })
        return d_

    def Data(self) -> typing.List[int]:
        return list(ctypes.string_at(self.data, self._dataLength))

    def Feature(self) -> typing.Tuple:
        return (self._blfObjType, self.id, self.channel)

    def TypeStr(self) -> str:
        return 'CanMessage2'

    def DirStr(self) -> str:
        dir_flag_ = self.flags & 0x01
        return self.INDEX_MAP_DIR_STR[dir_flag_]

class LinMessagePy(BlfIoStruct):
    _fields_ =[
        ('channel', ctypes.c_uint16),
        ('id', ctypes.c_uint8),
        ('dlc', ctypes.c_uint8),
        ('data', ctypes.c_uint8*8),
        ('fsmId', ctypes.c_uint8),
        ('fsmState', ctypes.c_uint8),
        ('headerTime', ctypes.c_uint8),
        ('fullTime', ctypes.c_uint8),
        ('crc', ctypes.c_uint16),
        ('dir', ctypes.c_uint8),
        ('reservedLinMessage1', ctypes.c_uint8),
        ('reservedLinMessage2', ctypes.c_uint32),
        ('_dataLength', ctypes.c_uint16),
    ]
    INDEX_MAP_DIR_STR = ['Rx', 'Tx', 'TxReq']
    def __init__(
        self,
        channel:int=0,
        id:int=0,
        dlc:int=0,
        data:typing.List[int]=[],
        fsmId:int=0,
        fsmState:int=0,
        headerTime:int=0,
        fullTime:int=0,
        crc:int=0,
        dir:int=0,
        children:dict = dict(),
        reservedLinMessage1:int=0,
        reservedLinMessage2:int=0) -> None:
        '''
        LinMessage Object
        :param channel:int channel
        :param id:int lin id
        :param dlc:int dlc
        :param data:list[int] 数据
        :param fsmId:int Slave Identifier in the Final State Machine
        :param fsmState:int State Identifier of a Slave in the Final State
        :param headerTime:int Duration of the frame header [in bit times]
        :param fullTime:int Duration of the entire frame [in bit times]
        :param crc:int crc
        :param dir:int 0:Rx 1:Tx 2:Tx Request
        :param reservedLinMessage1: 保留
        :param reservedLinMessage2: 保留
        '''
        super().__init__() 
        self.channel = channel
        self.id = id
        self.dlc = dlc
        self.data = (ctypes.c_uint8*8)(*data)
        self._dataLength = min(len(data), 8)
        self.fsmId = fsmId
        self.fsmState = fsmState
        self.headerTime = headerTime
        self.fullTime = fullTime
        self.crc = crc
        self.dir = dir
        self.children = children
        self.reservedLinMessage1 = reservedLinMessage1
        self.reservedLinMessage2 = reservedLinMessage2
        self._blfObjType = BLF_ObjectType.LIN_MESSAGE

    def ToDict(self) -> dict:
        d_ = super().ToDict()
        d_.update({
            'channel': self.channel,
            'id': self.id,
            'dlc': self.dlc,
            'data': list(ctypes.string_at(self.data, self._dataLength)),
            'fsmId': self.fsmId,
            'fsmState': self.fsmState,
            'headerTime': self.headerTime,
            'fullTime': self.fullTime,
            'crc': self.crc,
            'dir': self.dir,
            'children':self.children,
            'reservedLinMessage1': self.reservedLinMessage1,
            'reservedLinMessage2': self.reservedLinMessage2,
        })
        return d_

    def Data(self) -> typing.List[int]:
        return list(ctypes.string_at(self.data, self._dataLength))

    def Feature(self) -> typing.Tuple:
        # return super().Feature()
        return (self._blfObjType, self.id, self.channel)

    def TypeStr(self) -> str:
        return 'LinMessage'

    def DirStr(self) -> str:
        return self.INDEX_MAP_DIR_STR[self.dir]

class LinMessage2Py(BlfIoStruct):
    _fields_ =[
        ('data', ctypes.c_uint8*8),
        ('crc', ctypes.c_uint16),
        ('dir', ctypes.c_uint8),
        ('simulated', ctypes.c_uint8),
        ('isEtf', ctypes.c_uint8),
        ('etfAssocIndex', ctypes.c_uint8),
        ('etfAssocEtfId', ctypes.c_uint8),
        ('fsmId', ctypes.c_uint8),
        ('fsmState', ctypes.c_uint8),
        ('reservedLinMessage1', ctypes.c_uint8),
        ('reservedLinMessage2', ctypes.c_uint16),
        ('respBaudrate', ctypes.c_uint32),
        ('exactHeaderBaudrate', ctypes.c_double),
        ('earlyStopbitOffset', ctypes.c_uint32),
        ('earlyStopbitOffsetResponse', ctypes.c_uint32),
        ('apiMajor', ctypes.c_uint8),
        ('_dataLength', ctypes.c_uint16),
    ]
    INDEX_MAP_DIR_STR = ['Rx', 'Tx', 'TxReq']
    def __init__(
        self,
        data:typing.List[int]=[],
        crc:int=0,
        dir:int=0,
        simulated:int=0,
        isEtf:int=0,
        etfAssocIndex:int=0,
        etfAssocEtfId:int=0,
        fsmId:int=0,
        fsmState:int=0,
        reservedLinMessage1:int=0,
        reservedLinMessage2:int=0,
        respBaudrate:int=0,
        exactHeaderBaudrate:float=0.0,
        earlyStopbitOffset:int=0,
        earlyStopbitOffsetResponse:int=0,
        apiMajor:int=3,        
        ) -> None:
        '''
        LinMessage2 Object
        :param data:list[int] 数据
        :param crc:int crc
        :param dir:int 0:Rx 1:Tx 2:Tx Request
        :param simulated:int 0:真报文 1:仿真报文
        :param isEtf:int Flag indicating whether this frame is Event-Triggered one
            - 0:not ETF
            - 1:ETF
        :param etfAssocIndex:int Unconditional frame associated with ETF - serial index
        :param etfAssocEtfId:int Unconditional frame associated with ETF - id of ETF
        :param fsmId:int Slave Identifier in the Final State
        :param fsmState:int State Identifier of a Slave in the
        :param reservedLinMessage1:int 保留
        :param reservedLinMessage2:int 保留
        :param respBaudrate:int Response baudrate of the event in bit/sec
        :param exactHeaderBaudrate:double Exact baudrate of the header in bit/sec
        :param earlyStopbitOffset:int Early stop bit offset for UART timestamps in ns
        :param earlyStopbitOffsetResponse:int Early stop bit offset in frame response for UART timestamps in ns
        :param apiMajor:int API major number (see FileStatistics)
        '''
        super().__init__()
        self.data = (ctypes.c_uint8*8)(*data)
        self._dataLength = min(len(data), 8)
        self.crc = crc
        self.dir = dir
        self.simulated = simulated
        self.isEtf = isEtf
        self.etfAssocIndex = etfAssocIndex
        self.etfAssocEtfId = etfAssocEtfId
        self.fsmId = fsmId
        self.fsmState = fsmState
        self.reservedLinMessage1 = reservedLinMessage1
        self.reservedLinMessage2 = reservedLinMessage2
        self.respBaudrate = respBaudrate
        self.exactHeaderBaudrate = exactHeaderBaudrate
        self.earlyStopbitOffset = earlyStopbitOffset
        self.earlyStopbitOffsetResponse = earlyStopbitOffsetResponse
        self.apiMajor = apiMajor
        self._blfObjType = BLF_ObjectType.LIN_MESSAGE2

    def ToDict(self) -> dict:
        d_ = super().ToDict()
        d_.update({
            'data': list(ctypes.string_at(self.data, self._dataLength)),
            'crc': self.crc,
            'dir': self.dir,
            'simulated': self.simulated,
            'isEtf': self.isEtf,
            'etfAssocIndex': self.etfAssocIndex,
            'etfAssocEtfId': self.etfAssocEtfId,
            'fsmId': self.fsmId,
            'fsmState': self.fsmState,
            'reservedLinMessage1': self.reservedLinMessage1,
            'reservedLinMessage2': self.reservedLinMessage2,
            'respBaudrate': self.respBaudrate,
            'exactHeaderBaudrate': self.exactHeaderBaudrate,
            'earlyStopbitOffset': self.earlyStopbitOffset,
            'earlyStopbitOffsetResponse': self.earlyStopbitOffsetResponse,
            'apiMajor': self.apiMajor,
        })
        return d_

    def Data(self) -> typing.List[int]:
        return list(ctypes.string_at(self.data, self._dataLength))

    def Feature(self) -> typing.Tuple:
        return super().Feature()

    def TypeStr(self) -> str:
        return 'LinMessage2'

    def DirStr(self) -> str:
        return self.INDEX_MAP_DIR_STR[self.dir]

class LinFramePy(BlfIoStruct) :
    def __init__(self,
        name: str = '',
        channel: int = 0,
        data: typing.List[int] = [],
        children: typing.Dict[str, typing.Any] = {}) -> None:
        super().__init__()
        self.name = name
        self.channel = channel
        self.data = data
        self.children = children
        self._blfObjType = BLF_ObjectType.LIN_FRAME

    def TypeStr(self) -> str:
        return 'LinFrame'
    
    def Feature(self) -> typing.Tuple:
        return (self.name, self.channel)

    def ToDict(self) -> dict:
        d_ = super().ToDict()
        d_.update({
            'name': self.name,
            'channel': self.channel,
            'data': self.data, 
            'children': self.children,
        })
        return d_
        
class EthernetFramePy(BlfIoStruct):
    _fields_ =[
        ('sourceAddress', ctypes.c_uint8*6),
        ('channel', ctypes.c_uint16),
        ('destinationAddress', ctypes.c_uint8*6),
        ('dir', ctypes.c_uint16),
        ('type', ctypes.c_uint16),
        ('tpid', ctypes.c_uint16),
        ('tci', ctypes.c_uint16),
        ('payLoadLength', ctypes.c_uint16),
        ('reservedEthernetFrame', ctypes.c_uint64),
        ('payLoad', ctypes.c_uint8*65535),
        ('_payloadLength', ctypes.c_uint16),
    ]
    INDEX_MAP_DIR_STR = ['Rx', 'Tx', 'TxReq']
    def __init__(
        self,
        sourceAddress:typing.List[int]=[0,0,0,0,0,0],
        channel:int=0,
        destinationAddress:typing.List[int]=[0,0,0,0,0,0],
        dir:int=0,
        type:int=0,
        tpid:int=0,
        tci:int=0,
        payLoadLength:int=0,
        reservedEthernetFrame:int=0,
        payLoad:typing.List[int]=[]) -> None:
        super().__init__()
        '''
        EthernetFramePy Object
        :param sourceAddress:list[int] 源地址
        :param channel:int channel
        :param destinationAddress:list[int] 目的地址
        :param dir:int 方向
            - 0:Rx
            - 1:Tx
            - 2:TxRq
        :param type:int EtherType which indicates protocol for Ethernet payload data, See Ethernet standard specification for valid values
        :param tpid:int TPID when VLAN tag valid, zero when no VLAN. See Ethernet standard specification.
        :param tci:int TCI when VLAND tag valid, zero when no VLAN. See Ethernet standard specification.
        :param payLoadLength:int Number of valid payLoad bytes Length of Ethernet payload data in bytes. Max. 1500 Bytes (without Ethernet header)
        :param reservedEthernetFrame:int 保留
        :param payLoad:list[int] payLoad Max 1500 data bytes per frame Ethernet payload data (without Ethernet header)
        '''
        self.sourceAddress = (ctypes.c_uint8*6)(*sourceAddress)
        self.channel = channel
        self.destinationAddress = (ctypes.c_uint8*6)(*destinationAddress)
        self.dir = dir
        self.type = type
        self.tpid = tpid
        self.tci = tci
        self.payLoadLength = payLoadLength
        self.reservedEthernetFrame = reservedEthernetFrame
        self.payLoad = (ctypes.c_uint8*65535)(*payLoad)
        self._payloadLength = len(payLoad)
        self._blfObjType = BLF_ObjectType.ETHERNET_FRAME

    def ToDict(self) -> dict:
        # return super().ToDict()
        d_ = super().ToDict()
        d_.update({
            'sourceAddress': list(ctypes.string_at(self.sourceAddress, 6)),
            'channel': self.channel,
            'destinationAddress': list(ctypes.string_at(self.destinationAddress, 6)),
            'dir': self.dir,
            'type': self.type,
            'tpid': self.tpid,
            'tci': self.tci,
            'payLoadLength': self.payLoadLength,
            'reservedEthernetFrame': self.reservedEthernetFrame,
            'payLoad': list(ctypes.string_at(self.payLoad, self._payloadLength)),
        })
        return d_

    def Data(self) -> typing.List[int]:
        return list(ctypes.string_at(self.payLoad, self._payloadLength))

    def Feature(self) -> typing.Tuple:
        # return super().Feature()
        return (self._blfObjType, self.sourceAddress, self.destinationAddress, self.channel)

    def SourceAddress(self) -> typing.List[int]:
        '''
        获取源地址的 list 形式
        '''
        return list(ctypes.string_at(self.sourceAddress, 6))

    def DestinationAddress(self) -> typing.List[int]:
        '''
        获取目的地址的 list 形式
        '''
        return list(ctypes.string_at(self.destinationAddress, 6))

    def SourceAddressStr(self) -> str:
        '''
        获取源地址的 str 形式
        '''
        return ':'.join(['{0}'.format(x_) for x_ in self.SourceAddress()])

    def DestinationAddressStr(self) -> str:
        '''
        获取目的地址的 str 形式
        '''
        return ':'.join(['{0}'.format(x_) for x_ in self.DestinationAddress()])

    def TypeStr(self) -> str:
        return 'EtherentFrame'

    def DirStr(self) -> str:
        return self.INDEX_MAP_DIR_STR[self.dir]

class CanISignalIPduPy(BlfIoStruct):
    def __init__(
        self,
        name: str = '',
        channel: int = 0,
        data: typing.List[int] = [],
        children: typing.Dict[str, typing.Any] = {}) -> None:
        '''
        带解析的 CanISignalIPdu 对象
        :param name:str pdu 的名字
        :param channel:int 通道
        :param children:dict
        '''
        super().__init__()
        self.channel = channel
        self.name = name
        self.data = data
        self.children = children
        self._blfObjType = BLF_ObjectType.CAN_I_SIGNAL_I_PDU

    def TypeStr(self) -> str:
        return 'CanISignalIPdu'
    
    def Feature(self) -> typing.Tuple:
        return (self.name, self.channel)

    def ToDict(self) -> dict:
        d_ = super().ToDict()
        d_.update({
            'name': self.name,
            'channel': self.channel,
            'data': self.data, 
            'children': self.children,
        })
        return d_

class SomeIpFramePy(BlfIoStruct) :
    INDEX_MAP_DIR_STR = ['tx', 'rx']
    def __init__(
            self,
            proto:str = str(),
            src_ip :str = str(),
            src_port :str = str(),
            dest_ip :str = str(),
            dest_port :str = str(),
            if_type :str = str(),
            srv_id :int = 0,
            srv_name :str = str(),
            inst_id:int = 0,
            if_id : int = 0,
            if_name :str = str(),
            msg_type :int =0,
            session_id :int = 0,
            payload :list = list(),
            context :dict = dict(),
            dir:str = str(),
            children:dict = dict()
        ) -> None:
        super().__init__()
        self.proto = proto
        self.src_ip = src_ip
        self.src_port = src_port
        self.dest_ip =dest_ip
        self.dest_port = dest_port
        self.if_type = if_type
        self.srv_id = srv_id
        self.srv_name = srv_name
        self.inst_id = inst_id
        self.if_id = if_id
        self.if_name = if_name
        self.msg_type = msg_type
        self.payload = payload
        self.context = context
        self.dir = dir
        self.children = children
        self.session_id = session_id
        self._blfObjType = BLF_ObjectType.ETH_SOMEIP

    def ToDict(self) -> dict:
        d_ =  super().ToDict()
        d_.update({
            'dir':self.dir,
            'src_ip':self.src_ip,
            'src_port':self.src_port,
            'dest_ip':self.dest_ip,
            'dest_port':self.dest_port,
            'proto':self.proto,
            'if_type':self.if_type,
            'srv_id':self.srv_id,
            'srv_name':self.srv_name,
            'inst_id':self.inst_id,
            'if_id':self.if_id,
            'if_name':self.if_name,
            'msg_type':self.msg_type,
            'session_id':self.session_id,
            'payload':self.payload,
            'context':self.context,
            'children':{
                'Service':{
                    'Name':self.srv_name,
                    'ServiceId':self.srv_id,
                    'InstanceId':self.inst_id
                },
                'Interface':{
                    'Name':self.if_name,
                    'Type':self.if_type,
                    'InterfaceId':self.if_id,
                    'MsgType':self.msg_type,
                    'Payload':self.payload,
                    'Context':self.context,
                }   
            }
        })
        return d_
    
    def  Data(self) -> typing.List[int]:
        return self.payload
    
    def Feature(self) -> typing.Tuple:
        # return super().Feature()
        return (self._blfObjType, self.src_ip, self.src_port,self.dest_ip,self.dest_port)

    def TypeStr(self) -> str:
        return 'SomeIpMessage'

    def DirStr(self) -> str:
        return self.INDEX_MAP_DIR_STR[self.dir]

class SomeIpSDFramePy(BlfIoStruct) :
    INDEX_MAP_DIR_STR = ['tx', 'rx']
    def __init__(
            self,
            proto:str = str(),
            src_ip :str = str(),
            src_port :str = str(),
            dest_ip :str = str(),
            dest_port :str = str(),
            dir:str = str(),
            children:dict = dict(),
            data:list = list()
        ) -> None:
        super().__init__()
        self.proto = proto,
        self.src_ip = src_ip
        self.src_port = src_port
        self.dest_ip =dest_ip
        self.dest_port = dest_port
        self.dir = dir
        self.children = children
        
        self.data = data
        # print('recv data -======',list(self.data))
        self._blfObjType = BLF_ObjectType.ETH_SOMEIP_SD
    
    def ToDict(self) -> dict:
        d_ = super().ToDict()
        d_.update({
            'dir':self.dir,
            'src_ip':self.src_ip,
            'src_port':self.src_port,
            'dest_ip':self.dest_ip,
            'dest_port':self.dest_port,
            'proto':self.proto,
            'children':self.children,
            'data':self.data
        })
        return d_
        
    def Data(self) -> typing.List[int]:
        return self.data

    def Feature(self) -> typing.Tuple:
        # return super().Feature()
        return (self._blfObjType)
    
    def TypeStr(self) -> str:
        return 'SomeIpSDMessage'

    def DirStr(self) -> str:
        return self.INDEX_MAP_DIR_STR[self.dir]





# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import Common_pb2 as Common__pb2
from . import LinParserNode_pb2 as LinParserNode__pb2


class LinParserNodeStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddDbfile = channel.unary_unary(
                '/LinParserNode.LinParserNode/AddDbfile',
                request_serializer=Common__pb2.file_path.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.SetChannelConfig = channel.unary_unary(
                '/LinParserNode.LinParserNode/SetChannelConfig',
                request_serializer=LinParserNode__pb2.lin_channel_config.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.SetNodeSimulation = channel.unary_unary(
                '/LinParserNode.LinParserNode/SetNodeSimulation',
                request_serializer=LinParserNode__pb2.lin_node_config.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.SetFrameSimulation = channel.unary_unary(
                '/LinParserNode.LinParserNode/SetFrameSimulation',
                request_serializer=LinParserNode__pb2.lin_frame_config.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.Clear = channel.unary_unary(
                '/LinParserNode.LinParserNode/Clear',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.ClearSubscribe = channel.unary_unary(
                '/LinParserNode.LinParserNode/ClearSubscribe',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.ClearDbfile = channel.unary_unary(
                '/LinParserNode.LinParserNode/ClearDbfile',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.GetStatus = channel.unary_unary(
                '/LinParserNode.LinParserNode/GetStatus',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=LinParserNode__pb2.lin_parser_status.FromString,
                )
        self.GetLdfJsonTree = channel.unary_unary(
                '/LinParserNode.LinParserNode/GetLdfJsonTree',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=LinParserNode__pb2.lin_ldf_json.FromString,
                )


class LinParserNodeServicer(object):
    """Missing associated documentation comment in .proto file."""

    def AddDbfile(self, request, context):
        """添加一个 DB 文件
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetChannelConfig(self, request, context):
        """配置某个channel
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetNodeSimulation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetFrameSimulation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Clear(self, request, context):
        """清空所有配置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearSubscribe(self, request, context):
        """清除所有订阅
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearDbfile(self, request, context):
        """清空所有dbfile
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStatus(self, request, context):
        """获取状态
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLdfJsonTree(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LinParserNodeServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AddDbfile': grpc.unary_unary_rpc_method_handler(
                    servicer.AddDbfile,
                    request_deserializer=Common__pb2.file_path.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'SetChannelConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.SetChannelConfig,
                    request_deserializer=LinParserNode__pb2.lin_channel_config.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'SetNodeSimulation': grpc.unary_unary_rpc_method_handler(
                    servicer.SetNodeSimulation,
                    request_deserializer=LinParserNode__pb2.lin_node_config.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'SetFrameSimulation': grpc.unary_unary_rpc_method_handler(
                    servicer.SetFrameSimulation,
                    request_deserializer=LinParserNode__pb2.lin_frame_config.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'Clear': grpc.unary_unary_rpc_method_handler(
                    servicer.Clear,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'ClearSubscribe': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearSubscribe,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'ClearDbfile': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearDbfile,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'GetStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStatus,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=LinParserNode__pb2.lin_parser_status.SerializeToString,
            ),
            'GetLdfJsonTree': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLdfJsonTree,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=LinParserNode__pb2.lin_ldf_json.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'LinParserNode.LinParserNode', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LinParserNode(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def AddDbfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinParserNode.LinParserNode/AddDbfile',
            Common__pb2.file_path.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetChannelConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinParserNode.LinParserNode/SetChannelConfig',
            LinParserNode__pb2.lin_channel_config.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetNodeSimulation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinParserNode.LinParserNode/SetNodeSimulation',
            LinParserNode__pb2.lin_node_config.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetFrameSimulation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinParserNode.LinParserNode/SetFrameSimulation',
            LinParserNode__pb2.lin_frame_config.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Clear(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinParserNode.LinParserNode/Clear',
            Common__pb2.empty.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearSubscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinParserNode.LinParserNode/ClearSubscribe',
            Common__pb2.empty.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearDbfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinParserNode.LinParserNode/ClearDbfile',
            Common__pb2.empty.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinParserNode.LinParserNode/GetStatus',
            Common__pb2.empty.SerializeToString,
            LinParserNode__pb2.lin_parser_status.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLdfJsonTree(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinParserNode.LinParserNode/GetLdfJsonTree',
            Common__pb2.empty.SerializeToString,
            LinParserNode__pb2.lin_ldf_json.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import typing
import uuid
import copy

class ZoneSenderObject(object):
    ''' ZoneSender 中的基础数据对象
    '''
    def __init__(self) -> None:
        # self._triggerFuntion = None
        self.name = uuid.uuid4().hex
        self.context = dict()
    
    @staticmethod
    def From(obj):
        ''' [static] 从 obj 中构造 对象
        :param obj: 需要重写实现具体的功能
        '''
        return None

    def ToDict(self) -> 'dict':
        ''' 转成 dict 数据结构
        :return: dict 该数据结构的 dict 表达
        '''
        return dict()


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import Common_pb2 as Common__pb2
from . import LinStackNode_pb2 as LinStackNode__pb2


class LinStackNodeStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Reset = channel.unary_unary(
                '/LinStackNode.LinStackNode/Reset',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.SetConfig = channel.unary_unary(
                '/LinStackNode.LinStackNode/SetConfig',
                request_serializer=LinStackNode__pb2.lin_stack_configs.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.StartLinStack = channel.unary_unary(
                '/LinStackNode.LinStackNode/StartLinStack',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.StopLinStack = channel.unary_unary(
                '/LinStackNode.LinStackNode/StopLinStack',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.SetMessageSimulation = channel.unary_unary(
                '/LinStackNode.LinStackNode/SetMessageSimulation',
                request_serializer=LinStackNode__pb2.lin_message_config.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.SetHeaderSimulation = channel.unary_unary(
                '/LinStackNode.LinStackNode/SetHeaderSimulation',
                request_serializer=LinStackNode__pb2.lin_header_config.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.SetMessageData = channel.unary_unary(
                '/LinStackNode.LinStackNode/SetMessageData',
                request_serializer=LinStackNode__pb2.lin_message_data.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.GetStatus = channel.unary_unary(
                '/LinStackNode.LinStackNode/GetStatus',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=LinStackNode__pb2.lin_stack_status.FromString,
                )
        self.ClearSubscribe = channel.unary_unary(
                '/LinStackNode.LinStackNode/ClearSubscribe',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )


class LinStackNodeServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Reset(self, request, context):
        """复位 LinStackNode
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetConfig(self, request, context):
        """设置 LinStack 的配置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartLinStack(self, request, context):
        """启动 LinStack
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopLinStack(self, request, context):
        """关闭 LinStack
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetMessageSimulation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetHeaderSimulation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetMessageData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStatus(self, request, context):
        """获取 LinStack 的状态
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearSubscribe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LinStackNodeServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Reset': grpc.unary_unary_rpc_method_handler(
                    servicer.Reset,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'SetConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.SetConfig,
                    request_deserializer=LinStackNode__pb2.lin_stack_configs.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'StartLinStack': grpc.unary_unary_rpc_method_handler(
                    servicer.StartLinStack,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'StopLinStack': grpc.unary_unary_rpc_method_handler(
                    servicer.StopLinStack,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'SetMessageSimulation': grpc.unary_unary_rpc_method_handler(
                    servicer.SetMessageSimulation,
                    request_deserializer=LinStackNode__pb2.lin_message_config.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'SetHeaderSimulation': grpc.unary_unary_rpc_method_handler(
                    servicer.SetHeaderSimulation,
                    request_deserializer=LinStackNode__pb2.lin_header_config.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'SetMessageData': grpc.unary_unary_rpc_method_handler(
                    servicer.SetMessageData,
                    request_deserializer=LinStackNode__pb2.lin_message_data.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'GetStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStatus,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=LinStackNode__pb2.lin_stack_status.SerializeToString,
            ),
            'ClearSubscribe': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearSubscribe,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'LinStackNode.LinStackNode', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LinStackNode(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Reset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinStackNode.LinStackNode/Reset',
            Common__pb2.empty.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinStackNode.LinStackNode/SetConfig',
            LinStackNode__pb2.lin_stack_configs.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartLinStack(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinStackNode.LinStackNode/StartLinStack',
            Common__pb2.empty.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopLinStack(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinStackNode.LinStackNode/StopLinStack',
            Common__pb2.empty.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetMessageSimulation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinStackNode.LinStackNode/SetMessageSimulation',
            LinStackNode__pb2.lin_message_config.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetHeaderSimulation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinStackNode.LinStackNode/SetHeaderSimulation',
            LinStackNode__pb2.lin_header_config.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetMessageData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinStackNode.LinStackNode/SetMessageData',
            LinStackNode__pb2.lin_message_data.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinStackNode.LinStackNode/GetStatus',
            Common__pb2.empty.SerializeToString,
            LinStackNode__pb2.lin_stack_status.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearSubscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LinStackNode.LinStackNode/ClearSubscribe',
            Common__pb2.empty.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LogReplayNode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Common_pb2 as Common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13LogReplayNode.proto\x12\rLogReplayNode\x1a\x0c\x43ommon.proto\"e\n\x12lin_message_decode\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\r\x12\n\n\x02id\x18\x03 \x01(\r\x12\x12\n\ndecode_str\x18\x04 \x01(\t\"1\n\x0flin_decode_role\x12\x10\n\x08\x63hannels\x18\x01 \x03(\r\x12\x0c\n\x04ldfs\x18\x02 \x03(\t\"T\n\x0f\x63\x61n_decode_role\x12\x18\n\x10\x63\x61n_db_file_path\x18\x01 \x01(\t\x12\x10\n\x08\x63hannels\x18\x02 \x03(\r\x12\x15\n\rcluster_names\x18\x03 \x03(\t\"0\n\x08\x64\x65\x63ode_n\x12\x15\n\rblf_file_path\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"i\n\rdecode_result\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x13\n\x0bstart_index\x18\x02 \x01(\r\x12\x12\n\nstop_index\x18\x03 \x01(\r\x12\x0f\n\x07is_stop\x18\x04 \x01(\x08\"B\n\rblf_file_info\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x11\n\tfile_info\x18\x02 \x01(\t\"E\n\x0blog_request\x12$\n\tfile_path\x18\x01 \x01(\x0b\x32\x11.Common.file_path\x12\x10\n\x08log_flag\x18\x02 \x01(\r2\xe0\x04\n\rLogReplayNode\x12\x38\n\x08StartLog\x12\x1a.LogReplayNode.log_request\x1a\x0e.Common.result\"\x00\x12\x37\n\x0cGetLogStatus\x12\r.Common.empty\x1a\x16.Common.generic_string\"\x00\x12\x37\n\x07StopLog\x12\x1a.LogReplayNode.log_request\x1a\x0e.Common.result\"\x00\x12<\n\x10\x41\x64\x64LinDecodeRole\x12\x16.Common.generic_string\x1a\x0e.Common.result\"\x00\x12<\n\x10\x41\x64\x64\x43\x61nDecodeRole\x12\x16.Common.generic_string\x1a\x0e.Common.result\"\x00\x12\x46\n\x0bReplayNextN\x12\x17.LogReplayNode.decode_n\x1a\x1c.LogReplayNode.decode_result\"\x00\x12\x35\n\x0eOpenReplayFile\x12\x11.Common.file_path\x1a\x0e.Common.result\"\x00\x12\x36\n\x0f\x43loseReplayFile\x12\x11.Common.file_path\x1a\x0e.Common.result\"\x00\x12\x46\n\x11GetReplayFileInfo\x12\x11.Common.file_path\x1a\x1c.LogReplayNode.blf_file_info\"\x00\x12(\n\x05Reset\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x62\x06proto3')



_LIN_MESSAGE_DECODE = DESCRIPTOR.message_types_by_name['lin_message_decode']
_LIN_DECODE_ROLE = DESCRIPTOR.message_types_by_name['lin_decode_role']
_CAN_DECODE_ROLE = DESCRIPTOR.message_types_by_name['can_decode_role']
_DECODE_N = DESCRIPTOR.message_types_by_name['decode_n']
_DECODE_RESULT = DESCRIPTOR.message_types_by_name['decode_result']
_BLF_FILE_INFO = DESCRIPTOR.message_types_by_name['blf_file_info']
_LOG_REQUEST = DESCRIPTOR.message_types_by_name['log_request']
lin_message_decode = _reflection.GeneratedProtocolMessageType('lin_message_decode', (_message.Message,), {
  'DESCRIPTOR' : _LIN_MESSAGE_DECODE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.lin_message_decode)
  })
_sym_db.RegisterMessage(lin_message_decode)

lin_decode_role = _reflection.GeneratedProtocolMessageType('lin_decode_role', (_message.Message,), {
  'DESCRIPTOR' : _LIN_DECODE_ROLE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.lin_decode_role)
  })
_sym_db.RegisterMessage(lin_decode_role)

can_decode_role = _reflection.GeneratedProtocolMessageType('can_decode_role', (_message.Message,), {
  'DESCRIPTOR' : _CAN_DECODE_ROLE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.can_decode_role)
  })
_sym_db.RegisterMessage(can_decode_role)

decode_n = _reflection.GeneratedProtocolMessageType('decode_n', (_message.Message,), {
  'DESCRIPTOR' : _DECODE_N,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.decode_n)
  })
_sym_db.RegisterMessage(decode_n)

decode_result = _reflection.GeneratedProtocolMessageType('decode_result', (_message.Message,), {
  'DESCRIPTOR' : _DECODE_RESULT,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.decode_result)
  })
_sym_db.RegisterMessage(decode_result)

blf_file_info = _reflection.GeneratedProtocolMessageType('blf_file_info', (_message.Message,), {
  'DESCRIPTOR' : _BLF_FILE_INFO,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.blf_file_info)
  })
_sym_db.RegisterMessage(blf_file_info)

log_request = _reflection.GeneratedProtocolMessageType('log_request', (_message.Message,), {
  'DESCRIPTOR' : _LOG_REQUEST,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.log_request)
  })
_sym_db.RegisterMessage(log_request)

_LOGREPLAYNODE = DESCRIPTOR.services_by_name['LogReplayNode']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LIN_MESSAGE_DECODE._serialized_start=52
  _LIN_MESSAGE_DECODE._serialized_end=153
  _LIN_DECODE_ROLE._serialized_start=155
  _LIN_DECODE_ROLE._serialized_end=204
  _CAN_DECODE_ROLE._serialized_start=206
  _CAN_DECODE_ROLE._serialized_end=290
  _DECODE_N._serialized_start=292
  _DECODE_N._serialized_end=340
  _DECODE_RESULT._serialized_start=342
  _DECODE_RESULT._serialized_end=447
  _BLF_FILE_INFO._serialized_start=449
  _BLF_FILE_INFO._serialized_end=515
  _LOG_REQUEST._serialized_start=517
  _LOG_REQUEST._serialized_end=586
  _LOGREPLAYNODE._serialized_start=589
  _LOGREPLAYNODE._serialized_end=1197
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ShareMemNode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Common_pb2 as Common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12ShareMemNode.proto\x12\x0cShareMemNode\x1a\x0c\x43ommon.proto2>\n\x0cShareMemNode\x12.\n\nGetVersion\x12\r.Common.empty\x1a\x0f.Common.version\"\x00\x62\x06proto3')



_SHAREMEMNODE = DESCRIPTOR.services_by_name['ShareMemNode']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SHAREMEMNODE._serialized_start=50
  _SHAREMEMNODE._serialized_end=112
# @@protoc_insertion_point(module_scope)



import logging
from logging import handlers
from pathlib import Path

FILE_PATH = str(Path(__file__).parent.resolve())

print(FILE_PATH)

# 按时间分割文件
logger = logging.getLogger() 
logger.setLevel(logging.DEBUG)
formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s : %(message)s")
log_file_handler = handlers.TimedRotatingFileHandler(filename=FILE_PATH + "/log", when="M", interval=1, backupCount=1, encoding='utf-8')
log_file_handler.setFormatter(formatter)
# log_file_handler.setLevel(logging.DEBUG)
log_file_handler.suffix += ".log"
logger.addHandler(log_file_handler)


logger.critical('测试- critical')
logger.error('测试 error')
logger.warning('测试 warning')
logger.info('测试 info')
logger.debug('测试 debug')




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LinStackNode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Common_pb2 as Common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12LinStackNode.proto\x12\x0cLinStackNode\x1a\x0c\x43ommon.proto\"?\n\x12lin_message_config\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04simu\x18\x02 \x01(\x08\x12\x0f\n\x07\x63hannel\x18\x03 \x01(\x05\"2\n\x11lin_header_config\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\x05\x12\x0c\n\x04simu\x18\x01 \x01(\x08\"1\n\x10lin_message_data\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x02 \x03(\x05\"9\n\x10lin_stack_config\x12\x14\n\x0chardwareType\x18\x01 \x01(\t\x12\x0f\n\x07\x61ppName\x18\x02 \x01(\t\"C\n\x11lin_stack_configs\x12.\n\x06\x63onfig\x18\x01 \x03(\x0b\x32\x1e.LinStackNode.lin_stack_config\"V\n\x10lin_stack_status\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x12\n\nstr_status\x18\x03 \x01(\t2\xa6\x04\n\x0cLinStackNode\x12(\n\x05Reset\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12>\n\tSetConfig\x12\x1f.LinStackNode.lin_stack_configs\x1a\x0e.Common.result\"\x00\x12\x30\n\rStartLinStack\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12/\n\x0cStopLinStack\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12J\n\x14SetMessageSimulation\x12 .LinStackNode.lin_message_config\x1a\x0e.Common.result\"\x00\x12H\n\x13SetHeaderSimulation\x12\x1f.LinStackNode.lin_header_config\x1a\x0e.Common.result\"\x00\x12\x42\n\x0eSetMessageData\x12\x1e.LinStackNode.lin_message_data\x1a\x0e.Common.result\"\x00\x12<\n\tGetStatus\x12\r.Common.empty\x1a\x1e.LinStackNode.lin_stack_status\"\x00\x12\x31\n\x0e\x43learSubscribe\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x62\x06proto3')



_LIN_MESSAGE_CONFIG = DESCRIPTOR.message_types_by_name['lin_message_config']
_LIN_HEADER_CONFIG = DESCRIPTOR.message_types_by_name['lin_header_config']
_LIN_MESSAGE_DATA = DESCRIPTOR.message_types_by_name['lin_message_data']
_LIN_STACK_CONFIG = DESCRIPTOR.message_types_by_name['lin_stack_config']
_LIN_STACK_CONFIGS = DESCRIPTOR.message_types_by_name['lin_stack_configs']
_LIN_STACK_STATUS = DESCRIPTOR.message_types_by_name['lin_stack_status']
lin_message_config = _reflection.GeneratedProtocolMessageType('lin_message_config', (_message.Message,), {
  'DESCRIPTOR' : _LIN_MESSAGE_CONFIG,
  '__module__' : 'LinStackNode_pb2'
  # @@protoc_insertion_point(class_scope:LinStackNode.lin_message_config)
  })
_sym_db.RegisterMessage(lin_message_config)

lin_header_config = _reflection.GeneratedProtocolMessageType('lin_header_config', (_message.Message,), {
  'DESCRIPTOR' : _LIN_HEADER_CONFIG,
  '__module__' : 'LinStackNode_pb2'
  # @@protoc_insertion_point(class_scope:LinStackNode.lin_header_config)
  })
_sym_db.RegisterMessage(lin_header_config)

lin_message_data = _reflection.GeneratedProtocolMessageType('lin_message_data', (_message.Message,), {
  'DESCRIPTOR' : _LIN_MESSAGE_DATA,
  '__module__' : 'LinStackNode_pb2'
  # @@protoc_insertion_point(class_scope:LinStackNode.lin_message_data)
  })
_sym_db.RegisterMessage(lin_message_data)

lin_stack_config = _reflection.GeneratedProtocolMessageType('lin_stack_config', (_message.Message,), {
  'DESCRIPTOR' : _LIN_STACK_CONFIG,
  '__module__' : 'LinStackNode_pb2'
  # @@protoc_insertion_point(class_scope:LinStackNode.lin_stack_config)
  })
_sym_db.RegisterMessage(lin_stack_config)

lin_stack_configs = _reflection.GeneratedProtocolMessageType('lin_stack_configs', (_message.Message,), {
  'DESCRIPTOR' : _LIN_STACK_CONFIGS,
  '__module__' : 'LinStackNode_pb2'
  # @@protoc_insertion_point(class_scope:LinStackNode.lin_stack_configs)
  })
_sym_db.RegisterMessage(lin_stack_configs)

lin_stack_status = _reflection.GeneratedProtocolMessageType('lin_stack_status', (_message.Message,), {
  'DESCRIPTOR' : _LIN_STACK_STATUS,
  '__module__' : 'LinStackNode_pb2'
  # @@protoc_insertion_point(class_scope:LinStackNode.lin_stack_status)
  })
_sym_db.RegisterMessage(lin_stack_status)

_LINSTACKNODE = DESCRIPTOR.services_by_name['LinStackNode']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LIN_MESSAGE_CONFIG._serialized_start=50
  _LIN_MESSAGE_CONFIG._serialized_end=113
  _LIN_HEADER_CONFIG._serialized_start=115
  _LIN_HEADER_CONFIG._serialized_end=165
  _LIN_MESSAGE_DATA._serialized_start=167
  _LIN_MESSAGE_DATA._serialized_end=216
  _LIN_STACK_CONFIG._serialized_start=218
  _LIN_STACK_CONFIG._serialized_end=275
  _LIN_STACK_CONFIGS._serialized_start=277
  _LIN_STACK_CONFIGS._serialized_end=344
  _LIN_STACK_STATUS._serialized_start=346
  _LIN_STACK_STATUS._serialized_end=432
  _LINSTACKNODE._serialized_start=435
  _LINSTACKNODE._serialized_end=985
# @@protoc_insertion_point(module_scope)
